@@ -13,13 +13,16 @@ module: proxmox_kvm
 short_description: Management of Qemu(KVM) Virtual Machines in Proxmox VE cluster.
 description:
   - Allows you to create/delete/stop Qemu(KVM) Virtual Machines in Proxmox VE cluster.
+  - From community.general 4.0.0 on, there will be no default values, see I(proxmox_default_behavior).
 author: "Abdoul Bah (@helldorado) <bahabdoul at gmail.com>"
 options:
   acpi:
     description:
       - Specify if ACPI should be enabled/disabled.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(yes). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: bool
-    default: 'yes'
   agent:
     description:
       - Specify if the QEMU Guest Agent should be enabled/disabled.
@@ -29,7 +32,6 @@ options:
       - Pass arbitrary arguments to kvm.
       - This option is for experts only!
     type: str
-    default: "-serial unix:/var/run/qemu-server/VMID.serial,server,nowait"
   api_host:
     description:
       - Specify the target host of the Proxmox VE cluster.
@@ -45,17 +47,31 @@ options:
       - Specify the password to authenticate with.
       - You can use C(PROXMOX_PASSWORD) environment variable.
     type: str
+  api_token_id:
+    description:
+      - Specify the token ID.
+    type: str
+    version_added: 1.3.0
+  api_token_secret:
+    description:
+      - Specify the token secret.
+    type: str
+    version_added: 1.3.0
   autostart:
     description:
       - Specify if the VM should be automatically restarted after crash (currently ignored in PVE API).
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(no). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: bool
-    default: 'no'
   balloon:
     description:
       - Specify the amount of RAM for the VM in MB.
       - Using zero disables the balloon driver.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(0). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: int
-    default: 0
   bios:
     description:
       - Specify the BIOS implementation.
@@ -65,12 +81,37 @@ options:
     description:
       - Specify the boot order -> boot on floppy C(a), hard disk C(c), CD-ROM C(d), or network C(n).
       - You can combine to set order.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(cnd). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: str
-    default: cnd
   bootdisk:
     description:
       - Enable booting from specified disk. C((ide|sata|scsi|virtio)\d+)
     type: str
+  cicustom:
+    description:
+      - 'cloud-init: Specify custom files to replace the automatically generated ones at start.'
+    type: str
+    version_added: 1.3.0
+  cipassword:
+    description:
+      - 'cloud-init: password of default user to create.'
+    type: str
+    version_added: 1.3.0
+  citype:
+    description:
+      - 'cloud-init: Specifies the cloud-init configuration format.'
+      - The default depends on the configured operating system type (C(ostype)).
+      - We use the C(nocloud) format for Linux, and C(configdrive2) for Windows.
+    type: str
+    choices: ['nocloud', 'configdrive2']
+    version_added: 1.3.0
+  ciuser:
+    description:
+      - 'cloud-init: username of default user to create.'
+    type: str
+    version_added: 1.3.0
   clone:
     description:
       - Name of VM to be cloned. If C(vmid) is setted, C(clone) can take arbitrary value but required for initiating the clone.
@@ -78,13 +119,17 @@ options:
   cores:
     description:
       - Specify number of cores per socket.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(1). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: int
-    default: 1
   cpu:
     description:
       - Specify emulated CPU type.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(kvm64). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: str
-    default: kvm64
   cpulimit:
     description:
       - Specify if CPU usage will be limited. Value 0 indicates no CPU limit.
@@ -94,8 +139,10 @@ options:
     description:
       - Specify CPU weight for a VM.
       - You can disable fair-scheduler configuration by setting this to 0
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(1000). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: int
-    default: 1000
   delete:
     description:
       - Specify a list of settings you want to delete.
@@ -114,15 +161,21 @@ options:
     description:
       - Allow to force stop VM.
       - Can be used with states C(stopped) and C(restarted).
-    default: no
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(no). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: bool
   format:
     description:
       - Target drive's backing file's data format.
       - Used only with clone
+      - Use I(format=unspecified) and I(full=false) for a linked clone.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(qcow2). If I(proxmox_default_behavior) is set to C(no_defaults),
+        not specifying this option is equivalent to setting it to C(unspecified).
+        Note that the default value of I(proxmox_default_behavior) changes in community.general 4.0.0.
     type: str
-    default: qcow2
-    choices: [ "cloop", "cow", "qcow", "qcow2", "qed", "raw", "vmdk" ]
+    choices: [ "cloop", "cow", "qcow", "qcow2", "qed", "raw", "vmdk", "unspecified" ]
   freeze:
     description:
       - Specify if PVE should freeze CPU at startup (use 'c' monitor command to start execution).
@@ -165,6 +218,19 @@ options:
       - C(size) is the size of the disk in GB.
       - C(format) is the drive's backing file's data format. C(qcow2|raw|subvol).
     type: dict
+  ipconfig:
+    description:
+      - 'cloud-init: Set the IP configuration.'
+      - A hash/dictionary of network ip configurations. C(ipconfig='{"key":"value", "key":"value"}').
+      - Keys allowed are - C(ipconfig[n]) where 0 ≤ n ≤ network interfaces.
+      - Values allowed are -  C("[gw=<GatewayIPv4>] [,gw6=<GatewayIPv6>] [,ip=<IPv4Format/CIDR>] [,ip6=<IPv6Format/CIDR>]").
+      - 'cloud-init: Specify IP addresses and gateways for the corresponding interface.'
+      - IP addresses use CIDR notation, gateways are optional but they should be in the same subnet of specified IP address.
+      - The special string 'dhcp' can be used for IP addresses to use DHCP, in which case no explicit gateway should be provided.
+      - For IPv6 the special string 'auto' can be used to use stateless autoconfiguration.
+      - If cloud-init is enabled and neither an IPv4 nor an IPv6 address is specified, it defaults to using dhcp on IPv4.
+    type: dict
+    version_added: 1.3.0
   keyboard:
     description:
       - Sets the keyboard layout for VNC server.
@@ -172,8 +238,10 @@ options:
   kvm:
     description:
       - Enable/disable KVM hardware virtualization.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(yes). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: bool
-    default: 'yes'
   localtime:
     description:
       - Sets the real time clock to local time.
@@ -192,8 +260,10 @@ options:
   memory:
     description:
       - Memory size in MB for instance.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(512). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: int
-    default: 512
   migrate_downtime:
     description:
       - Sets maximum tolerated downtime (in seconds) for migrations.
@@ -208,6 +278,13 @@ options:
       - Specifies the VM name. Only used on the configuration web interface.
       - Required only for C(state=present).
     type: str
+  nameservers:
+    description:
+      - 'cloud-init: DNS server IP address(es).'
+      - If unset, PVE host settings are used.
+    type: list
+    elements: str
+    version_added: 1.3.0
   net:
     description:
       - A hash/dictionary of network interfaces for the VM. C(net='{"key":"value", "key":"value"}').
@@ -240,18 +317,26 @@ options:
       - C(memory) Amount of memory this NUMA node provides.
       - C(policy) NUMA allocation policy.
     type: dict
+  numa_enabled:
+    description:
+      - Enables NUMA.
+    type: bool
   onboot:
     description:
       - Specifies whether a VM will be started during system bootup.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(yes). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: bool
-    default: 'yes'
   ostype:
     description:
       - Specifies guest operating system. This is used to enable special optimization/features for specific operating systems.
       - The l26 is Linux 2.6/3.X Kernel.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(l26). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: str
     choices: ['other', 'wxp', 'w2k', 'w2k3', 'w2k8', 'wvista', 'win7', 'win8', 'win10', 'l24', 'l26', 'solaris']
-    default: l26
   parallel:
     description:
       - A hash/dictionary of map host parallel devices. C(parallel='{"key":"value", "key":"value"}').
@@ -297,6 +382,13 @@ options:
       - Specifies the SCSI controller model.
     type: str
     choices: ['lsi', 'lsi53c810', 'virtio-scsi-pci', 'virtio-scsi-single', 'megasas', 'pvscsi']
+  searchdomains:
+    description:
+      - 'cloud-init: Sets DNS search domain(s).'
+      - If unset, PVE host settings are used.
+    type: list
+    elements: str
+    version_added: 1.3.0
   serial:
     description:
       - A hash/dictionary of serial device to create inside the VM. C('{"key":"value", "key":"value"}').
@@ -327,8 +419,15 @@ options:
   sockets:
     description:
       - Sets the number of CPU sockets. (1 - N).
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(1). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: int
-    default: 1
+  sshkeys:
+    description:
+      - 'cloud-init: SSH key to assign to the default user. NOT TESTED with multiple keys but a multi-line value should work.'
+    type: str
+    version_added: 1.3.0
   startdate:
     description:
       - Sets the initial date of the real time clock.
@@ -354,8 +453,10 @@ options:
   tablet:
     description:
       - Enables/disables the USB tablet device.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(no). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: bool
-    default: 'no'
   target:
     description:
       - Target node. Only allowed if the original VM is on shared storage.
@@ -368,8 +469,10 @@ options:
   template:
     description:
       - Enables/disables the template.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(no). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: bool
-    default: 'no'
   timeout:
     description:
       - Timeout for operations.
@@ -380,6 +483,7 @@ options:
       - If C(yes), the VM will be updated with new value.
       - Cause of the operations of the API and security reasons, I have disabled the update of the following parameters
       - C(net, virtio, ide, sata, scsi). Per example updating C(net) update the MAC address and C(virtio) create always new disk...
+      - Update of C(pool) is disabled. It needs an additional API endpoint not covered by this module.
     type: bool
     default: 'no'
   validate_certs:
@@ -394,9 +498,11 @@ options:
   vga:
     description:
       - Select VGA type. If you want to use high resolution modes (>= 1280x1024x16) then you should use option 'std' or 'vmware'.
+      - If I(proxmox_default_behavior) is set to C(compatiblity) (the default value), this
+        option has a default of C(std). Note that the default value of I(proxmox_default_behavior)
+        changes in community.general 4.0.0.
     type: str
     choices: ['std', 'cirrus', 'vmware', 'qxl', 'serial0', 'serial1', 'serial2', 'serial3', 'qxl2', 'qxl3', 'qxl4']
-    default: std
   virtio:
     description:
       - A hash/dictionary of volume used as VIRTIO hard disk. C(virtio='{"key":"value", "key":"value"}').
@@ -415,6 +521,25 @@ options:
     description:
       - Creates a virtual hardware watchdog device.
     type: str
+  proxmox_default_behavior:
+    description:
+      - Various module options used to have default values. This cause problems when
+        user expects different behavior from proxmox by default or fill options which cause
+        problems when they have been set.
+      - The default value is C(compatibility), which will ensure that the default values
+        are used when the values are not explicitly specified by the user.
+      - From community.general 4.0.0 on, the default value will switch to C(no_defaults). To avoid
+        deprecation warnings, please set I(proxmox_default_behavior) to an explicit
+        value.
+      - This affects the I(acpi), I(autostart), I(balloon), I(boot), I(cores), I(cpu),
+        I(cpuunits), I(force), I(format), I(kvm), I(memory), I(onboot), I(ostype), I(sockets),
+        I(tablet), I(template), I(vga), options.
+    type: str
+    choices:
+      - compatibility
+      - no_defaults
+    version_added: "1.3.0"
+
 requirements: [ "proxmoxer", "requests" ]
 '''
 
@@ -443,7 +568,9 @@ EXAMPLES = '''
     api_host: helldorado
     name: spynal
     node: sabrewulf
-    net: '{"net0":"virtio,bridge=vmbr1,rate=200", "net1":"e1000,bridge=vmbr2,"}'
+    net:
+      net0: 'virtio,bridge=vmbr1,rate=200'
+      net1: 'e1000,bridge=vmbr2'
 
 - name: Create new VM with one network interface, three virto hard disk, 4 cores, and 2 vcpus
   community.general.proxmox_kvm:
@@ -452,8 +579,12 @@ EXAMPLES = '''
     api_host: helldorado
     name: spynal
     node: sabrewulf
-    net: '{"net0":"virtio,bridge=vmbr1,rate=200"}'
-    virtio: '{"virtio0":"VMs_LVM:10", "virtio1":"VMs:2,format=qcow2", "virtio2":"VMs:5,format=raw"}'
+    net:
+      net0: 'virtio,bridge=vmbr1,rate=200'
+    virtio:
+      virtio0: 'VMs_LVM:10'
+      virtio1: 'VMs:2,format=qcow2'
+      virtio2: 'VMs:5,format=raw'
     cores: 4
     vcpus: 2
 
@@ -472,6 +603,22 @@ EXAMPLES = '''
     format: qcow2
     timeout: 500
 
+- name: >
+    Create linked clone VM with only source VM name.
+    The VM source is spynal.
+    The target VM name is zavala
+  community.general.proxmox_kvm:
+    api_user: root@pam
+    api_password: secret
+    api_host: helldorado
+    clone: spynal
+    name: zavala
+    node: sabrewulf
+    storage: VMs
+    full: no
+    format: unspecified
+    timeout: 500
+
 - name: Clone VM with source vmid and target newid and raw format
   community.general.proxmox_kvm:
     api_user: root@pam
@@ -486,7 +633,7 @@ EXAMPLES = '''
     format: raw
     timeout: 300
 
-- name: Create new VM and lock it for snapashot
+- name: Create new VM and lock it for snapshot
   community.general.proxmox_kvm:
     api_user: root@pam
     api_password: secret
@@ -504,6 +651,43 @@ EXAMPLES = '''
     node: sabrewulf
     protection: yes
 
+- name: Create new VM using cloud-init with a username and password
+  community.general.proxmox_kvm:
+    node: sabrewulf
+    api_user: root@pam
+    api_password: secret
+    api_host: helldorado
+    name: spynal
+    ide:
+      ide2: 'local:cloudinit,format=qcow2'
+    ciuser: mylinuxuser
+    cipassword: supersecret
+    searchdomains: 'mydomain.internal'
+    nameservers: 1.1.1.1
+    net:
+      net0: 'virtio,bridge=vmbr1,tag=77'
+    ipconfig:
+      ipconfig0: 'ip=192.168.1.1/24,gw=192.168.1.1'
+
+- name: Create new VM using Cloud-Init with an ssh key
+  community.general.proxmox_kvm:
+    node: sabrewulf
+    api_user: root@pam
+    api_password: secret
+    api_host: helldorado
+    name: spynal
+    ide:
+      ide2: 'local:cloudinit,format=qcow2'
+    sshkeys: 'ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAILJkVm98B71lD5XHfihwcYHE9TVpsJmK1vR1JcaU82L+'
+    searchdomains: 'mydomain.internal'
+    nameservers:
+      - '1.1.1.1'
+      - '8.8.8.8'
+    net:
+      net0: 'virtio,bridge=vmbr1,tag=77'
+    ipconfig:
+      ipconfig0: 'ip=192.168.1.1/24'
+
 - name: Start VM
   community.general.proxmox_kvm:
     api_user: root@pam
@@ -634,6 +818,7 @@ import re
 import time
 import traceback
 from distutils.version import LooseVersion
+from ansible.module_utils.six.moves.urllib.parse import quote
 
 try:
     from proxmoxer import ProxmoxAPI
@@ -737,6 +922,7 @@ def wait_for_task(module, proxmox, node, taskid):
 def create_vm(module, proxmox, vmid, newid, node, name, memory, cpu, cores, sockets, update, **kwargs):
     # Available only in PVE 4
     only_v4 = ['force', 'protection', 'skiplock']
+    only_v6 = ['ciuser', 'cipassword', 'sshkeys', 'ipconfig']
 
     # valide clone parameters
     valid_clone_params = ['format', 'full', 'pool', 'snapname', 'storage', 'target']
@@ -750,13 +936,25 @@ def create_vm(module, proxmox, vmid, newid, node, name, memory, cpu, cores, sock
     kwargs = dict((k, v) for k, v in kwargs.items() if v is not None)
     kwargs.update(dict([k, int(v)] for k, v in kwargs.items() if isinstance(v, bool)))
 
-    # The features work only on PVE 4
+    # The features work only on PVE 4+
     if PVE_MAJOR_VERSION < 4:
         for p in only_v4:
             if p in kwargs:
                 del kwargs[p]
 
+    # The features work only on PVE 6
+    if PVE_MAJOR_VERSION < 6:
+        for p in only_v6:
+            if p in kwargs:
+                del kwargs[p]
+
+    # 'sshkeys' param expects an urlencoded string
+    if 'sshkeys' in kwargs:
+        urlencoded_ssh_keys = quote(kwargs['sshkeys'], safe='')
+        kwargs['sshkeys'] = str(urlencoded_ssh_keys)
+
     # If update, don't update disk (virtio, ide, sata, scsi) and network interface
+    # pool parameter not supported by qemu/<vmid>/config endpoint on "update" (PVE 6.2) - only with "create"
     if update:
         if 'virtio' in kwargs:
             del kwargs['virtio']
@@ -770,18 +968,30 @@ def create_vm(module, proxmox, vmid, newid, node, name, memory, cpu, cores, sock
             del kwargs['net']
         if 'force' in kwargs:
             del kwargs['force']
+        if 'pool' in kwargs:
+            del kwargs['pool']
 
-    # Convert all dict in kwargs to elements. For hostpci[n], ide[n], net[n], numa[n], parallel[n], sata[n], scsi[n], serial[n], virtio[n]
+    # Convert all dict in kwargs to elements. For hostpci[n], ide[n], net[n], numa[n], parallel[n], sata[n], scsi[n], serial[n], virtio[n], ipconfig[n]
     for k in list(kwargs.keys()):
         if isinstance(kwargs[k], dict):
             kwargs.update(kwargs[k])
             del kwargs[k]
 
-    # Rename numa_enabled  to numa. According the API documentation
+    # Rename numa_enabled to numa. According the API documentation
     if 'numa_enabled' in kwargs:
         kwargs['numa'] = kwargs['numa_enabled']
         del kwargs['numa_enabled']
 
+    # PVE api expects strings for the following params
+    if 'nameservers' in module.params:
+        nameservers = module.params.pop('nameservers')
+        if nameservers:
+            kwargs['nameserver'] = ' '.join(nameservers)
+    if 'searchdomains' in module.params:
+        searchdomains = module.params.pop('searchdomains')
+        if searchdomains:
+            kwargs['searchdomain'] = ' '.join(searchdomains)
+
     # -args and skiplock require root@pam user
     if module.params['api_user'] == "root@pam" and module.params['args'] is None:
         if not update:
@@ -845,79 +1055,90 @@ def proxmox_version(proxmox):
 def main():
     module = AnsibleModule(
         argument_spec=dict(
-            acpi=dict(type='bool', default=True),
+            acpi=dict(type='bool'),
             agent=dict(type='bool'),
-            args=dict(type='str', default=None),
+            args=dict(type='str'),
             api_host=dict(required=True),
-            api_user=dict(required=True),
             api_password=dict(no_log=True),
-            autostart=dict(type='bool', default=False),
-            balloon=dict(type='int', default=0),
+            api_token_id=dict(no_log=True),
+            api_token_secret=dict(no_log=True),
+            api_user=dict(required=True),
+            autostart=dict(type='bool'),
+            balloon=dict(type='int'),
             bios=dict(choices=['seabios', 'ovmf']),
-            boot=dict(type='str', default='cnd'),
+            boot=dict(type='str'),
             bootdisk=dict(type='str'),
+            cicustom=dict(type='str'),
+            cipassword=dict(type='str', no_log=True),
+            citype=dict(type='str', choices=['nocloud', 'configdrive2']),
+            ciuser=dict(type='str'),
             clone=dict(type='str', default=None),
-            cores=dict(type='int', default=1),
-            cpu=dict(type='str', default='kvm64'),
+            cores=dict(type='int'),
+            cpu=dict(type='str'),
             cpulimit=dict(type='int'),
-            cpuunits=dict(type='int', default=1000),
+            cpuunits=dict(type='int'),
             delete=dict(type='str', default=None),
             description=dict(type='str'),
             digest=dict(type='str'),
-            force=dict(type='bool', default=False),
-            format=dict(type='str', default='qcow2', choices=['cloop', 'cow', 'qcow', 'qcow2', 'qed', 'raw', 'vmdk']),
+            force=dict(type='bool'),
+            format=dict(type='str', choices=['cloop', 'cow', 'qcow', 'qcow2', 'qed', 'raw', 'vmdk', 'unspecified']),
             freeze=dict(type='bool'),
             full=dict(type='bool', default=True),
             hostpci=dict(type='dict'),
             hotplug=dict(type='str'),
             hugepages=dict(choices=['any', '2', '1024']),
-            ide=dict(type='dict', default=None),
+            ide=dict(type='dict'),
+            ipconfig=dict(type='dict'),
             keyboard=dict(type='str'),
-            kvm=dict(type='bool', default=True),
+            kvm=dict(type='bool'),
             localtime=dict(type='bool'),
             lock=dict(choices=['migrate', 'backup', 'snapshot', 'rollback']),
             machine=dict(type='str'),
-            memory=dict(type='int', default=512),
+            memory=dict(type='int'),
             migrate_downtime=dict(type='int'),
             migrate_speed=dict(type='int'),
             name=dict(type='str'),
+            nameservers=dict(type='list', elements='str'),
             net=dict(type='dict'),
             newid=dict(type='int', default=None),
             node=dict(),
             numa=dict(type='dict'),
             numa_enabled=dict(type='bool'),
-            onboot=dict(type='bool', default=True),
-            ostype=dict(default='l26', choices=['other', 'wxp', 'w2k', 'w2k3', 'w2k8', 'wvista', 'win7', 'win8', 'win10', 'l24', 'l26', 'solaris']),
+            onboot=dict(type='bool'),
+            ostype=dict(choices=['other', 'wxp', 'w2k', 'w2k3', 'w2k8', 'wvista', 'win7', 'win8', 'win10', 'l24', 'l26', 'solaris']),
             parallel=dict(type='dict'),
             pool=dict(type='str'),
             protection=dict(type='bool'),
             reboot=dict(type='bool'),
-            revert=dict(type='str', default=None),
+            revert=dict(type='str'),
             sata=dict(type='dict'),
             scsi=dict(type='dict'),
             scsihw=dict(choices=['lsi', 'lsi53c810', 'virtio-scsi-pci', 'virtio-scsi-single', 'megasas', 'pvscsi']),
             serial=dict(type='dict'),
+            searchdomains=dict(type='list', elements='str'),
             shares=dict(type='int'),
             skiplock=dict(type='bool'),
             smbios=dict(type='str'),
             snapname=dict(type='str'),
-            sockets=dict(type='int', default=1),
+            sockets=dict(type='int'),
+            sshkeys=dict(type='str'),
             startdate=dict(type='str'),
             startup=dict(),
             state=dict(default='present', choices=['present', 'absent', 'stopped', 'started', 'restarted', 'current']),
             storage=dict(type='str'),
-            tablet=dict(type='bool', default=False),
+            tablet=dict(type='bool'),
             target=dict(type='str'),
             tdf=dict(type='bool'),
-            template=dict(type='bool', default=False),
+            template=dict(type='bool'),
             timeout=dict(type='int', default=30),
             update=dict(type='bool', default=False),
             validate_certs=dict(type='bool', default=False),
-            vcpus=dict(type='int', default=None),
-            vga=dict(default='std', choices=['std', 'cirrus', 'vmware', 'qxl', 'serial0', 'serial1', 'serial2', 'serial3', 'qxl2', 'qxl3', 'qxl4']),
-            virtio=dict(type='dict', default=None),
+            vcpus=dict(type='int'),
+            vga=dict(choices=['std', 'cirrus', 'vmware', 'qxl', 'serial0', 'serial1', 'serial2', 'serial3', 'qxl2', 'qxl3', 'qxl4']),
+            virtio=dict(type='dict'),
             vmid=dict(type='int', default=None),
             watchdog=dict(),
+            proxmox_default_behavior=dict(type='str', choices=['compatibility', 'no_defaults']),
         ),
         mutually_exclusive=[('delete', 'revert'), ('delete', 'update'), ('revert', 'update'), ('clone', 'update'), ('clone', 'delete'), ('clone', 'revert')],
         required_one_of=[('name', 'vmid',)],
@@ -927,9 +1148,11 @@ def main():
     if not HAS_PROXMOXER:
         module.fail_json(msg='proxmoxer required for this module')
 
-    api_user = module.params['api_user']
     api_host = module.params['api_host']
     api_password = module.params['api_password']
+    api_token_id = module.params['api_token_id']
+    api_token_secret = module.params['api_token_secret']
+    api_user = module.params['api_user']
     clone = module.params['clone']
     cpu = module.params['cpu']
     cores = module.params['cores']
@@ -945,17 +1168,57 @@ def main():
     vmid = module.params['vmid']
     validate_certs = module.params['validate_certs']
 
-    # If password not set get it from PROXMOX_PASSWORD env
-    if not api_password:
-        try:
-            api_password = os.environ['PROXMOX_PASSWORD']
-        except KeyError as e:
-            module.fail_json(msg='You should set api_password param or use PROXMOX_PASSWORD environment variable')
+    if module.params['proxmox_default_behavior'] is None:
+        module.params['proxmox_default_behavior'] = 'compatibility'
+        module.deprecate(
+            'The proxmox_default_behavior option will change its default value from "compatibility" to '
+            '"no_defaults" in community.general 4.0.0. To remove this warning, please specify an explicit value for it now',
+            version='4.0.0', collection_name='community.general'
+        )
+    if module.params['proxmox_default_behavior'] == 'compatibility':
+        old_default_values = dict(
+            acpi=True,
+            autostart=False,
+            balloon=0,
+            boot='cnd',
+            cores=1,
+            cpu='kvm64',
+            cpuunits=1000,
+            force=False,
+            format='qcow2',
+            kvm=True,
+            memory=512,
+            ostype='l26',
+            sockets=1,
+            tablet=False,
+            template=False,
+            vga='std',
+        )
+        for param, value in old_default_values.items():
+            if module.params[param] is None:
+                module.params[param] = value
+
+    if module.params['format'] == 'unspecified':
+        module.params['format'] = None
+
+    auth_args = {'user': api_user}
+    if not (api_token_id and api_token_secret):
+        # If password not set get it from PROXMOX_PASSWORD env
+        if not api_password:
+            try:
+                api_password = os.environ['PROXMOX_PASSWORD']
+            except KeyError:
+                module.fail_json(msg='You should set api_password param or use PROXMOX_PASSWORD environment variable')
+        auth_args['password'] = api_password
+    else:
+        auth_args['token_name'] = api_token_id
+        auth_args['token_value'] = api_token_secret
 
     try:
-        proxmox = ProxmoxAPI(api_host, user=api_user, password=api_password, verify_ssl=validate_certs)
+        proxmox = ProxmoxAPI(api_host, verify_ssl=validate_certs, **auth_args)
         global PVE_MAJOR_VERSION
-        PVE_MAJOR_VERSION = 3 if proxmox_version(proxmox) < LooseVersion('4.0') else 4
+        version = proxmox_version(proxmox)
+        PVE_MAJOR_VERSION = 3 if version < LooseVersion('4.0') else version.version[0]
     except Exception as e:
         module.fail_json(msg='authorization on proxmox cluster failed with exception: %s' % e)
 
@@ -965,13 +1228,13 @@ def main():
         if state == 'present' and not update and not clone and not delete and not revert:
             try:
                 vmid = get_nextvmid(module, proxmox)
-            except Exception as e:
+            except Exception:
                 module.fail_json(msg="Can't get the next vmid for VM {0} automatically. Ensure your cluster state is good".format(name))
         else:
             clone_target = clone or name
             try:
                 vmid = get_vmid(proxmox, clone_target)[0]
-            except Exception as e:
+            except Exception:
                 vmid = -1
 
     if clone is not None:
@@ -979,7 +1242,7 @@ def main():
         if not newid:
             try:
                 newid = get_nextvmid(module, proxmox)
-            except Exception as e:
+            except Exception:
                 module.fail_json(msg="Can't get the next vmid for VM {0} automatically. Ensure your cluster state is good".format(name))
 
         # Ensure source VM name exists when cloning
@@ -1031,6 +1294,10 @@ def main():
                       bios=module.params['bios'],
                       boot=module.params['boot'],
                       bootdisk=module.params['bootdisk'],
+                      cicustom=module.params['cicustom'],
+                      cipassword=module.params['cipassword'],
+                      citype=module.params['citype'],
+                      ciuser=module.params['ciuser'],
                       cpulimit=module.params['cpulimit'],
                       cpuunits=module.params['cpuunits'],
                       description=module.params['description'],
@@ -1041,6 +1308,7 @@ def main():
                       hotplug=module.params['hotplug'],
                       hugepages=module.params['hugepages'],
                       ide=module.params['ide'],
+                      ipconfig=module.params['ipconfig'],
                       keyboard=module.params['keyboard'],
                       kvm=module.params['kvm'],
                       localtime=module.params['localtime'],
@@ -1065,6 +1333,7 @@ def main():
                       skiplock=module.params['skiplock'],
                       smbios1=module.params['smbios'],
                       snapname=module.params['snapname'],
+                      sshkeys=module.params['sshkeys'],
                       startdate=module.params['startdate'],
                       startup=module.params['startup'],
                       tablet=module.params['tablet'],
