@@ -97,6 +97,15 @@ def main():
         required_together=[['login_user', 'login_password']],
     )
 
+    try:
+        from collections import OrderedDict
+    except ImportError as excep:
+        try:
+            from ordereddict import OrderedDict
+        except ImportError as excep:
+            module.fail_json(msg='Cannot import OrderedDict class. You can probably install with: pip install ordereddict: %s'
+                             % to_native(excep))
+
     if not pymongo_found:
         module.fail_json(msg=missing_required_lib('pymongo'),
                          exception=PYMONGO_IMP_ERR)
@@ -152,7 +161,12 @@ def main():
             module.fail_json(msg='Unable to authenticate with MongoDB: %s' % to_native(excep))
 
         try:
-            client['admin'].command({"shutdown": 1, "force": force, "timeout": timeout})
+            cmd_doc = OrderedDict([
+                ('shutdown', 1),
+                ('force', force),
+                ('timeout', timeout)
+            ])
+            client['admin'].command(cmd_doc)
         except Exception as excep:
             if "connection closed" in str(excep):
                 result["changed"] = True
