@@ -47,7 +47,8 @@ aruba_provider_spec = {
     'timeout': dict(type='int'),
 }
 aruba_argument_spec = {
-    'provider': dict(type='dict', options=aruba_provider_spec)
+    'provider': dict(type='dict', options=aruba_provider_spec, removed_in_version='4.0.0',
+                     removed_from_collection='community.network')
 }
 
 aruba_top_spec = {
