@@ -1,10 +1,12 @@
-from __future__ import absolute_import
-
 """
 Created on Aug 16, 2016
 
 @author: Gaurav Rastogi (grastogi@avinetworks.com)
 """
+
+from __future__ import absolute_import, division, print_function
+__metaclass__ = type
+
 import os
 import re
 import logging
