@@ -73,7 +73,8 @@ cnos_provider_spec = {
 }
 
 cnos_argument_spec = {
-    'provider': dict(type='dict', options=cnos_provider_spec),
+    'provider': dict(type='dict', options=cnos_provider_spec, removed_in_version='4.0.0',
+                     removed_from_collection='community.network'),
 }
 
 command_spec = {
