@@ -7,7 +7,7 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-DOCUMENTATION = '''
+DOCUMENTATION = r'''
 module: vmware_host_iscsi
 short_description: Manage the iSCSI configuration of ESXi host
 author:
@@ -263,22 +263,20 @@ extends_documentation_fragment:
 - community.vmware.vmware.documentation
 '''
 
-EXAMPLES = '''
+EXAMPLES = r'''
 - name: Enable iSCSI of ESXi
-  vmware_host_iscsi:
+  community.vmware.vmware_host_iscsi:
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
-    validate_certs: no
     esxi_hostname: "{{ esxi_hostname }}"
     state: enabled
 
 - name: Add a dynamic target to iSCSI config of ESXi
-  vmware_host_iscsi:
+  community.vmware.vmware_host_iscsi:
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
-    validate_certs: no
     esxi_hostname: "{{ esxi_hostname }}"
     iscsi_config:
       vmhba_name: vmhba65
@@ -287,11 +285,10 @@ EXAMPLES = '''
     state: present
 
 - name: Add a static target to iSCSI config of ESXi
-  vmware_host_iscsi:
+  community.vmware.vmware_host_iscsi:
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
-    validate_certs: no
     esxi_hostname: "{{ esxi_hostname }}"
     iscsi_config:
       vmhba_name: vmhba65
@@ -301,11 +298,10 @@ EXAMPLES = '''
     state: present
 
 - name: Add VMKernels to iSCSI config of ESXi
-  vmware_host_iscsi:
+  community.vmware.vmware_host_iscsi:
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
-    validate_certs: no
     esxi_hostname: "{{ esxi_hostname }}"
     iscsi_config:
       vmhba_name: vmhba65
@@ -315,11 +311,10 @@ EXAMPLES = '''
     state: present
 
 - name: Use CHAP authentication
-  vmware_host_iscsi:
+  community.vmware.vmware_host_iscsi:
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
-    validate_certs: no
     esxi_hostname: "{{ esxi_hostname }}"
     iscsi_config:
       vmhba_name: vmhba65
@@ -331,11 +326,10 @@ EXAMPLES = '''
     state: present
 
 - name: Remove a dynamic target from iSCSI config of ESXi
-  vmware_host_iscsi:
+  community.vmware.vmware_host_iscsi:
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
-    validate_certs: no
     esxi_hostname: "{{ esxi_hostname }}"
     iscsi_config:
       vmhba_name: vmhba65
@@ -344,7 +338,7 @@ EXAMPLES = '''
     state: absent
 '''
 
-RETURN = '''
+RETURN = r'''
 iscsi_properties:
   description: Parameter return when system defaults config is changed.
   returned: changed
