@@ -7,16 +7,11 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-
-ANSIBLE_METADATA = {'metadata_version': '1.1',
-                    'status': ['preview'],
-                    'supported_by': 'certified'}
-
 DOCUMENTATION = r'''
 ---
 module: bigip_monitor_http
-short_description: Manages F5 BIG-IP LTM http monitors
-description: Manages F5 BIG-IP LTM http monitors.
+short_description: Manages F5 BIG-IP LTM HTTP monitors
+description: Manages F5 BIG-IP LTM HTTP monitors.
 version_added: "1.0.0"
 options:
   name:
@@ -37,16 +32,16 @@ options:
     type: str
   send:
     description:
-      - The send string for the monitor call. When creating a new monitor, if
-        this value is not provided, the default C(GET /\r\n) will be used.
+      - The Send string for the monitor call. When creating a new monitor, if
+        this value is not provided, the default C(GET /\r\n) is used.
     type: str
   receive:
     description:
-      - The receive string for the monitor call.
+      - The Receive string for the monitor call.
     type: str
   receive_disable:
     description:
-      - This setting works like C(receive), except that the system marks the node
+      - This setting works like C(receive), except the system marks the node
         or pool member disabled when its response matches the C(receive_disable)
         string but not C(receive). To use this setting, you must specify both
         C(receive_disable) and C(receive).
@@ -54,21 +49,19 @@ options:
   ip:
     description:
       - IP address part of the IP/port definition. If this parameter is not
-        provided when creating a new monitor, then the default value will be
-        '*'.
+        provided when creating a new monitor, the default value is '*'.
     type: str
   port:
     description:
       - Port address part of the IP/port definition. If this parameter is not
-        provided when creating a new monitor, then the default value will be
-        '*'. Note that if specifying an IP address, a value between 1 and 65535
-        must be specified.
+        provided when creating a new monitor, the default value is
+        '*'. If specifying an IP address, you must specify a value between 1 and 65535.
     type: str
   interval:
     description:
       - The interval specifying how frequently the monitor instance of this
         template will run. If this parameter is not provided when creating
-        a new monitor, then the default value will be 5. This value B(must)
+        a new monitor, the default value is 5. This value B(must)
         be less than the C(timeout) value.
     type: int
   timeout:
@@ -77,17 +70,17 @@ options:
         the monitor request. If the target responds within the set time
         period, it is considered up. If the target does not respond within
         the set time period, it is considered down. You can change this
-        number to any number you want, however, it should be 3 times the
+        to any number, however, it should be 3 times the
         interval number of seconds plus 1 second. If this parameter is not
-        provided when creating a new monitor, then the default value will be 16.
+        provided when creating a new monitor, the default value is 16.
     type: int
   time_until_up:
     description:
       - Specifies the amount of time in seconds after the first successful
-        response before a node will be marked up. A value of 0 will cause a
+        response before a node is marked up. A value of 0 causes a
         node to be marked up immediately after a valid response is received
         from the node. If this parameter is not provided when creating
-        a new monitor, then the default value will be 0.
+        a new monitor, the default value will be 0.
     type: int
   target_username:
     description:
@@ -114,7 +107,7 @@ options:
     default: Common
   state:
     description:
-      - When C(present), ensures that the monitor exists.
+      - When C(present), ensures the monitor exists.
       - When C(absent), ensures the monitor is removed.
     type: str
     choices:
@@ -181,7 +174,7 @@ ip:
   type: str
   sample: 10.12.13.14
 interval:
-  description: The new interval in which to run the monitor check.
+  description: The new interval at which to run the monitor check.
   returned: changed
   type: int
   sample: 2
@@ -201,6 +194,7 @@ reverse:
   type: bool
   sample: yes
 '''
+from datetime import datetime
 
 from ansible.module_utils.basic import (
     AnsibleModule, env_fallback
@@ -212,6 +206,8 @@ from ..module_utils.common import (
 )
 from ..module_utils.compare import cmp_str_with_none
 from ..module_utils.ipaddress import is_valid_ip
+from ..module_utils.icontrol import tmos_version
+from ..module_utils.teem import send_teem
 
 
 class Parameters(AnsibleF5Parameters):
@@ -514,6 +510,8 @@ class ModuleManager(object):
         return False
 
     def exec_module(self):
+        start = datetime.now().isoformat()
+        version = tmos_version(self.client)
         changed = False
         result = dict()
         state = self.want.state
@@ -528,6 +526,7 @@ class ModuleManager(object):
         result.update(**changes)
         result.update(dict(changed=changed))
         self._announce_deprecations(result)
+        send_teem(start, self.module, version)
         return result
 
     def _announce_deprecations(self, result):
