@@ -7,11 +7,6 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-
-ANSIBLE_METADATA = {'metadata_version': '1.1',
-                    'status': ['preview'],
-                    'supported_by': 'certified'}
-
 DOCUMENTATION = r'''
 ---
 module: bigip_policy
@@ -19,9 +14,9 @@ short_description: Manage general policy configuration on a BIG-IP
 description:
   - Manages general policy configuration on a BIG-IP. This module is best
     used in conjunction with the C(bigip_policy_rule) module. This module
-    can handle general configuration like setting the draft state of the policy,
-    the description, and things unrelated to the policy rules themselves.
-    It is also the first module that should be used when creating rules as
+    can handle general configuration, like setting the draft state of the policy,
+    the description, and items unrelated to the policy rules themselves.
+    It is also the first module that should be used when creating rules, as
     the C(bigip_policy_rule) module requires a policy parameter.
 version_added: "1.0.0"
 options:
@@ -29,7 +24,7 @@ options:
     description:
       - The description to attach to the policy.
       - This parameter is only supported on versions of BIG-IP >= 12.1.0. On earlier
-        versions it will simply be ignored.
+        versions it is simply ignored.
     type: str
   name:
     description:
@@ -38,10 +33,10 @@ options:
     required: True
   state:
     description:
-      - When C(state) is C(present), ensures that the policy exists and is
-        published. When C(state) is C(absent), ensures that the policy is removed,
+      - When C(state) is C(present), ensures the policy exists and is
+        published. When C(state) is C(absent), ensures the policy is removed,
         even if it is currently drafted.
-      - When C(state) is C(draft), ensures that the policy exists and is drafted.
+      - When C(state) is C(draft), ensures the policy exists and is drafted.
         When modifying rules, it is required that policies first be in a draft.
       - Drafting is only supported on versions of BIG-IP >= 12.1.0. On versions
         prior to that, specifying a C(state) of C(draft) will raise an error.
@@ -53,11 +48,11 @@ options:
     default: present
   strategy:
     description:
-      - Specifies the method to determine which actions get executed in the
-        case where there are multiple rules that match. When creating new
+      - Specifies the method to determine which actions get executed when
+        there are multiple rules that match. When creating new
         policies, the default is C(first).
       - This module does not allow you to specify the C(best) strategy to use.
-        It will choose the system default (C(/Common/best-match)) for you instead.
+        It will choose the system default (C(/Common/best-match)) instead.
     type: str
     choices:
       - first
@@ -65,10 +60,10 @@ options:
       - best
   rules:
     description:
-      - Specifies a list of rules that you want associated with this policy.
+      - Specifies a list of rules you want associated with this policy.
         The order of this list is the order they will be evaluated by BIG-IP.
         If the specified rules do not exist (for example when creating a new
-        policy) then they will be created.
+        policy) they will be created.
       - The C(conditions) for a default rule are C(all).
       - The C(actions) for a default rule are C(ignore).
       - The C(bigip_policy_rule) module can be used to create and edit existing
@@ -195,17 +190,19 @@ rules:
   sample: ['/Common/rule1', '/Common/rule2']
 '''
 import re
+from datetime import datetime
+from distutils.version import LooseVersion
 
 from ansible.module_utils.basic import (
     AnsibleModule, env_fallback
 )
-from distutils.version import LooseVersion
 
 from ..module_utils.bigip import F5RestClient
 from ..module_utils.common import (
     F5ModuleError, AnsibleF5Parameters, transform_name, f5_argument_spec, fq_name
 )
 from ..module_utils.icontrol import tmos_version
+from ..module_utils.teem import send_teem
 
 
 class Parameters(AnsibleF5Parameters):
@@ -564,6 +561,8 @@ class SimpleManager(BaseManager):
         return False
 
     def exec_module(self):
+        start = datetime.now().isoformat()
+        version = tmos_version(self.client)
         changed = False
         result = dict()
         state = self.want.state
@@ -582,6 +581,7 @@ class SimpleManager(BaseManager):
         result.update(dict(changed=changed))
         self._announce_deprecations()
         self._announce_warnings()
+        send_teem(start, self.module, version)
         return result
 
     def create(self):
@@ -756,6 +756,8 @@ class ComplexManager(BaseManager):
         return False
 
     def exec_module(self):
+        start = datetime.now().isoformat()
+        version = tmos_version(self.client)
         changed = False
         result = dict()
         state = self.want.state
@@ -768,6 +770,7 @@ class ComplexManager(BaseManager):
         changes = self.changes.to_return()
         result.update(**changes)
         result.update(dict(changed=changed))
+        send_teem(start, self.module, version)
         return result
 
     def should_update(self):
